# 🎨 Bookshelf Color

This datapack facilitate color conversion between various formats.

> “Color helps to express light, not the physical phenomenon, but the only light that really exists, that in the artist’s brain.”
>
> -- Henri Matisse

For more details and usage examples, check out the Bookshelf [documentation](https://docs.mcbookshelf.dev/en/latest/modules/color.html).


## 📖 About Bookshelf

This module is part of the [Bookshelf Library](https://docs.mcbookshelf.dev/en/latest/index.html), a modular library datapack designed to simplify complex systems in Minecraft. Explore the full range of modules and discover how Bookshelf can simplify your Minecraft creations!
